/*!
 * vue-auth-msal v1.0.1
 * (c) 2023 Shige Fukushima <shigeyf@outlook.com>
 * @license Apache-2.0
 */
'use strict';

var msalBrowser = require('@azure/msal-browser');
var vue = require('vue');

// packages/vue-auth-msal/src/packageMetadata.ts
/** @public */
const pkgName = 'vue-auth-msal';
/** @public */
const pkgVersion = '1.0.1';
/** @public */
const pkgBuildDate = '"2023-12-15T09:17:53.487Z"';

// packages/vue-auth-msal/src/injectionSymbols.ts
/**
 * @internal
 */
const msalPluginKey = Symbol();
/**
 * @internal
 */
const msalStateKey = Symbol();

// packages/vue-auth-msal/src/router/RouterGuard.ts
/**
 * Function registerRouterGuard
 * @param router
 * @internal
 */
function registerRouterGuard(router, msal) {
    const logger = msal.getLogger();
    // beforeEach
    /* eslint-disable @typescript-eslint/no-unused-vars */
    router.beforeEach(async (to, from) => {
        logger.verbose(`vue-router:beforeEach():Called`);
        // Commented to fix a logging bug.
        //logger.verbose(`vue-router:beforeEach():to = ${JSON.stringify(to)}`)
        //logger.verbose(`vue-router:beforeEach():from = ${JSON.stringify(from)}`)
        // the following lines are candidates for fix.
        //logger.verbose(`vue-router:beforeEach():to = ${JSON.stringify({ path: to.path, name: to.name })}`);
        //logger.verbose(`vue-router:beforeEach():from = ${JSON.stringify({ path: from.path, name: from.name })}`);
        // Block router navigation (and rendering) before masl initialization finished
        logger.verbose(`vue-router:beforeEach():Awaiting MsalPlugin Init`);
        await msal.waitInitPromise;
        logger.verbose(`vue-router:beforeEach():Finished MsalPlugin Init`);
        // true: allow the cuurent navigation.
        // false: cancel the current navigation.
        // If the browser URL was changed (either manually by the user or via back button),
        // it will be reset to that of the from route.
        let result = true;
        // Remove auth response hash from app URL when redirecting back to this app from AAD Auth.
        if (msal.getCurrentInteractionStaus() === msalBrowser.InteractionStatus.HandleRedirect) {
            // URL components in `hash` property are not encoded, while those in fullPath are encoded;
            // you cannot simply do String.replace() with `hash` property against `fullPath` property.
            const pathWithouHash = to.fullPath.split('#')[0];
            to.fullPath = pathWithouHash;
            to.hash = '';
            // `href` property contains `hash` but it's not a valid prop according to type definition
            // You don't likely need to replace `href` for hash removement.
            // To be clarified for future
        }
        // All matched routes (self and its parents) are populated into `matched` property as an array
        // Check if one of the mateched routes has meta:requiresAuth property
        if (to.matched.some((record) => record.meta.requiresAuth)) {
            logger.verbose(`vue-router:beforeEach():Invoke RouterGuard for MsalPlugin because of 'requiresAuth' = true`);
            const request = {
                ...msal.options.loginRequest,
                redirectStartPage: to.fullPath,
            };
            result = await isAuthenticated(msal.instance, msal.options.interactionType, request);
        }
        logger.verbose(`vue-router:beforeEach():Returned`);
        return result;
    });
}
/**
 *
 * @param instance
 * @param interactionType
 * @param loginRequest
 * @returns
 */
async function isAuthenticated(instance, interactionType, loginRequest) {
    // If your application uses redirects for interaction,
    // handleRedirectPromise must be called and awaited on each page load before determining if a user is signed in or not
    return instance
        .handleRedirectPromise()
        .then(() => {
        // One or more User account is already signed in.
        const accounts = instance.getAllAccounts();
        if (accounts.length > 0) {
            return true;
        }
        // User is not signed in and attempting to access protected route. Sign them in.
        if (interactionType === msalBrowser.InteractionType.Popup) {
            return instance
                .loginPopup(loginRequest)
                .then(() => true)
                .catch(() => false);
        }
        else if (interactionType === msalBrowser.InteractionType.Redirect) {
            return instance
                .loginRedirect(loginRequest)
                .then(() => true)
                .catch(() => false);
        }
        // Otherwise false: Blocked routing
        return false;
    })
        .catch(() => {
        // When error false: Blocked routing
        return false;
    });
}

// packages/vue-auth-msal/src/router/AuthNavigationClient.ts
// External Modules
/**
 * Class: AuthNavigationClient
 * Overriding the default NavigationClient which MSAL uses to navigate to other urls in your webpage.
 * @internal
 */
class AuthNavigationClient extends msalBrowser.NavigationClient {
    router;
    pca;
    constructor(router, pca) {
        super();
        this.router = router;
        this.pca = pca;
    }
    /**
     * Navigates to other pages within the same web application
     * @param url
     * @param options
     *
     * NOTE: this function will be called only when:
     *   - handleRedirectPromise() at 'Redirect' interaction client
     *     * When returning from the external and When loginRequestUrl is not equal with the page where 'Redirect' was triggered
     *   - logoutPopupAsync() at 'Popup' interaction client
     *     * When logging out via Popup interaction
     */
    async navigateInternal(url, options) {
        this.pca.getLogger().verbose('AuthNavigationClient:navigateInternal():Called');
        this.pca.getLogger().verbose(`AuthNavigationClient:navigateInternal():url = ${url}`);
        this.pca.getLogger().verbose(`AuthNavigationClient:navigateInternal():options = ${JSON.stringify(options)}`);
        const relativePath = url.replace(window.location.origin, '');
        if (options.noHistory) {
            this.router.replace(relativePath);
        }
        else {
            this.router.push(relativePath);
        }
        this.pca.getLogger().verbose('AuthNavigationClient:navigateInternal():Returned always false');
        return false;
    }
}

// packages/vue-auth-msal/src/utils/utilFuncs.ts
/**
 * Helper function to determine whether 2 arrays are equal
 * Used to avoid unnecessary state updates
 * @param arrayA
 * @param arrayB
 * @returns boolean
 * @internal
 */
function accountArraysAreEqual(arrayA, arrayB) {
    if (arrayA.length !== arrayB.length) {
        return false;
    }
    const comparisonArray = [...arrayB];
    return arrayA.every((elementA) => {
        const elementB = comparisonArray.shift();
        if (!elementA || !elementB) {
            return false;
        }
        return (elementA.homeAccountId === elementB.homeAccountId &&
            elementA.localAccountId === elementB.localAccountId &&
            elementA.username === elementB.username);
    });
}

// packages/vue-auth-msal/src/plugin.ts
/**
 * Function createMsal
 * Creates a Msal plugin instance to be used by the application
 * @public
 */
function createMsal(msalOptions) {
    const msalInstance = new MsalPlugin(msalOptions);
    return msalInstance;
}
/**
 * Class MsalPlugin
 * @public
 */
class MsalPlugin {
    // Plugin Contexts
    instance;
    options;
    // Private properties
    _state;
    _logger;
    _eventCallbacks;
    // Instance Initialization Awaiter
    _initResolver;
    waitInitPromise;
    constructor(msalOptions) {
        // Set default options
        this.options = {
            interactionType: msalBrowser.InteractionType.Redirect,
            loginRequest: { scopes: [] },
        };
        this.instance = new msalBrowser.PublicClientApplication(msalOptions.configuration);
        if (msalOptions.interactionType != undefined) {
            this.options.interactionType = msalOptions.interactionType;
        }
        if (msalOptions.loginRequest != undefined) {
            this.options.loginRequest = msalOptions.loginRequest;
        }
        // Initialize values for state
        this._state = vue.reactive({
            inProgress: msalBrowser.InteractionStatus.None,
            activeAccount: this.instance.getActiveAccount(),
            accounts: this.instance.getAllAccounts(),
        });
        // Reset Instance Initialization Awaiter
        this._initResolver = null;
        this.waitInitPromise = Promise.resolve();
        // Initialize private properties
        this.instance.initializeWrapperLibrary(pkgName, pkgVersion);
        this._logger = this.instance.getLogger().clone(pkgName, pkgVersion);
        this._eventCallbacks = [];
    }
    getLogger() {
        return this._logger;
    }
    getCurrentInteractionStaus() {
        return this._state.inProgress;
    }
    // Asynchronous install()
    async install(app, options) {
        this._logger.verbose('MsalPlugin:install():Called');
        //
        // Setup Router Extensions
        //   When vuejs/router is introduced
        //
        if (options.router != undefined) {
            this._logger.verbose('MsalPlugin:install:Initialize Router extension');
            // Set NavigationClient
            const navigationClient = new AuthNavigationClient(options.router, this.instance);
            this.instance.setNavigationClient(navigationClient);
            // Configure Router Guard
            registerRouterGuard(options.router, this);
        }
        //
        // Setup Plugin Contexts
        //
        this._logger.verbose('MsalPlugin:install:Initialize MsalState');
        app.provide(msalPluginKey, this);
        app.provide(msalStateKey, this._state);
        //
        // Configure MSAL App Instance
        //   1. Setup Event hooks
        //   2. Initialize Instance
        //   3. Setup HandleRedirect hook
        //
        this._logger.verbose('MsalPlugin:install:Initialize Event Callback Hooks');
        let id = null;
        // Hooks for Debug
        id = this.instance.addEventCallback((message) => {
            this._logger.verbose(`MsalPlugin:install:EventCallback:[ForDebug]:EventType: ${message.eventType}`);
        });
        this._eventCallbacks.push({ name: 'ForDebug', id: id });
        // Hooks for after LoginSuccess
        id = this.instance.addEventCallback((message) => {
            if (message.eventType === msalBrowser.EventType.LOGIN_SUCCESS) {
                this._logger.verbose(`MsalPlugin:install:EventCallback:[LoginSuccess]:Called`);
                if (message.payload) {
                    const result = message.payload;
                    this._logger.verbose(`MsalPlugin:install:EventCallback:[LoginSuccess]:Payload: ${JSON.stringify(result)}`);
                    if (result.account != null) {
                        this.setNewActiveAccount(result.account);
                    }
                }
                this._logger.verbose(`MsalPlugin:install:EventCallback:[LoginSuccess]:Returned`);
            }
        });
        this._eventCallbacks.push({ name: 'LoginSuccess', id: id });
        // Hooks for Accounts update
        id = this.instance.addEventCallback((message) => {
            switch (message.eventType) {
                case msalBrowser.EventType.LOGOUT_END:
                case msalBrowser.EventType.ACCOUNT_ADDED:
                case msalBrowser.EventType.ACCOUNT_REMOVED:
                case msalBrowser.EventType.LOGIN_SUCCESS:
                case msalBrowser.EventType.LOGIN_FAILURE:
                case msalBrowser.EventType.SSO_SILENT_SUCCESS:
                case msalBrowser.EventType.SSO_SILENT_FAILURE:
                case msalBrowser.EventType.ACQUIRE_TOKEN_SUCCESS:
                case msalBrowser.EventType.ACQUIRE_TOKEN_FAILURE:
                case msalBrowser.EventType.HANDLE_REDIRECT_END:
                    this._logger.verbose(`MsalPlugin:install:EventCallback:[AccountsUpdate]:Called`);
                    this.updateAccounts();
                    if (message.eventType === msalBrowser.EventType.LOGOUT_END) {
                        this.resetAccount();
                    }
                    this._logger.verbose(`MsalPlugin:install:EventCallback:[AccountsUpdate]:Returned`);
                    break;
            }
        });
        this._eventCallbacks.push({ name: 'AccountsUpdate', id: id });
        // Hooks for Status Updating
        id = this.instance.addEventCallback((message) => {
            this._logger.verbose(`MsalPlugin:install:EventCallback:[StatusUpdate]:Called`);
            this.updateStatusByMessage(message);
            this._logger.verbose(`MsalPlugin:install:EventCallback:[StatusUpdate]:Returned`);
        });
        this._eventCallbacks.push({ name: 'StatusUpdate', id: id });
        // Hooks for LogOutPopupEnd
        id = this.instance.addEventCallback((message) => {
            if (message.eventType === msalBrowser.EventType.LOGOUT_END && message.interactionType === msalBrowser.InteractionType.Popup) {
                this._logger.verbose(`MsalPlugin:install:EventCallback:[LogOutPopupEnd]:Called`);
                const router = options.router;
                if (router != undefined) {
                    const currentRoute = router.currentRoute.value;
                    if (currentRoute.meta.requiresAuth) {
                        if (currentRoute.meta.popupLogoutFallback != undefined) {
                            this._logger.info(`MsalPlugin:install:EventCallback:[LogOutPopupEnd]:Route to: ${currentRoute.meta.popupLogoutFallback}`);
                            router.push(currentRoute.meta.popupLogoutFallback);
                        }
                    }
                }
                this._logger.verbose(`MsalPlugin:install:EventCallback:[LogOutPopupEnd]:Returned`);
            }
        });
        this._eventCallbacks.push({ name: 'LogOutPopupEnd', id: id });
        // MSAL Instance Initialization
        this.waitInit();
        await this.instance.initialize().then(() => {
            // Added handleRedirectPromise null Hook for Redirect flow - Reset inProgress state
            this._logger.verbose(`MsalPlugin:install:instance.initialize finished`);
            this.instance
                .handleRedirectPromise()
                .then((response) => {
                if (response != null) {
                    this._logger.verbose(`MsalPlugin:install:handleRedirectPromise success response: ${JSON.stringify(response)}`);
                    if (response.account != null) {
                        this.setNewActiveAccount(response.account);
                    }
                }
                else {
                    this._logger.verbose(`MsalPlugin:install:handleRedirectPromise success response: null`);
                    this.resetAccount();
                    this.updateAccounts();
                }
            })
                .catch((error) => {
                // Handle errors (either in the library or coming back from the server)
                // Errors should be handled by listening to the LOGIN_FAILURE event
                this._logger.error(`MsalPlugin:install:handleRedirectPromise error: ${error}`);
            })
                .finally(() => {
                this._logger.verbose(`MsalPlugin:install:handleRedirectPromise:finally:Called`);
                // Logics for finally block
                this.resetInProgress();
            });
        });
        this.doneInit();
        this._logger.verbose('MsalPlugin:install():Returned');
    }
    //
    // State handling functions
    //
    updateStatusByMessage(message) {
        const _status = this._state.inProgress;
        const status = msalBrowser.EventMessageUtils.getInteractionStatusFromEvent(message, this._state.inProgress);
        if (status !== null) {
            this._state.inProgress = status;
            this._logger.info(`MsalPlugin:updateStatusByMessage:Updated from ${_status} to ${status}`);
        }
    }
    resetInProgress() {
        this._state.inProgress = msalBrowser.InteractionStatus.None;
        this._logger.info(`MsalPlugin:resetInProgress: inProgress to none`);
    }
    updateAccounts() {
        const accounts = this.instance.getAllAccounts();
        if (!accountArraysAreEqual(accounts, this._state.accounts)) {
            this._state.accounts = accounts;
            this._logger.info(`MsalPlugin:updateAccounts:Updated to: ${JSON.stringify(this._state.accounts)}`);
        }
    }
    setNewActiveAccount(account) {
        this.instance.setActiveAccount(account);
        this._state.activeAccount = this.instance.getActiveAccount();
        this._logger.info(`MsalPlugin:setNewActiveAccount: ${account.username}`);
    }
    resetAccount() {
        const accounts = this.instance.getAllAccounts();
        // No account is stored
        if (accounts.length === 0) {
            this._state.activeAccount = null;
            this._logger.info(`MsalPlugin:resetAccount: null`);
        }
        // One or more account are stored
        else if (accounts.length > 0) {
            const account = this._state.accounts[0];
            this.instance.setActiveAccount(account);
            this._state.activeAccount = account;
            this._logger.info(`MsalPlugin:resetAccount: ${account.username}`);
        }
    }
    //
    // Initialization control functions
    //
    waitInit() {
        if (this._initResolver == null) {
            this.waitInitPromise = new Promise((resolve) => (this._initResolver = resolve));
        }
    }
    doneInit() {
        if (this._initResolver != null) {
            this._initResolver();
            this._initResolver = null;
            this.waitInitPromise = Promise.resolve();
        }
    }
}

// packages/vue-auth-msal/src/composables/internals/useMsalPluginInstance.ts
/**
 * Function useMsalPluginInstance
 * @returns
 * @internal
 */
function useMsalPluginInstance() {
    const msalPluginInstance = vue.inject(msalPluginKey);
    if (msalPluginInstance == undefined) {
        throw 'useMsal*() cannot be used without installing vue-auth-msal plugin.';
    }
    return msalPluginInstance;
}

// packages/vue-auth-msal/src/composables/internals/useMsalState.ts
/**
 * Function useMsalState
 * @returns
 * @internal
 */
function useMsalState() {
    const msalState = vue.inject(msalStateKey);
    if (msalState == undefined) {
        throw 'useMsal*() cannot be used without installing vue-auth-msal plugin.';
    }
    return msalState;
}

// packages/vue-auth-msal/src/composables/useMsal.ts
// External Modules
/**
 * Function useMsal
 * @returns
 * @public
 */
function useMsal() {
    const plugin = useMsalPluginInstance();
    const interactionType = plugin.options.interactionType;
    const loginRequest = plugin.options.loginRequest;
    const logger = plugin.getLogger();
    const msal = plugin.instance;
    const msalState = useMsalState();
    // Setup Reactivity for components
    const { inProgress, accounts, activeAccount } = vue.toRefs(msalState);
    // Login
    const login = (loginRequestOverride) => {
        if (inProgress.value === msalBrowser.InteractionStatus.None) {
            logger.verbose(`useMsal.login():Called`);
            const request = loginRequestOverride != undefined ? loginRequestOverride : loginRequest;
            if (interactionType === msalBrowser.InteractionType.Popup) {
                logger.verbose(`useMsal.login():loginPopup triggered with ${JSON.stringify(request)}`);
                msal.loginPopup(request).catch((e) => {
                    if (e instanceof msalBrowser.BrowserAuthError &&
                        e.errorCode === msalBrowser.BrowserAuthErrorMessage.userCancelledError.code) {
                        logger.info(`useMsal.login():loginPopup user_cancelled`);
                    }
                    else {
                        logger.error(`useMsal.login():loginPopup error: ${JSON.stringify(e)}`);
                    }
                });
            }
            else if (interactionType == msalBrowser.InteractionType.Redirect) {
                logger.verbose(`useMsal.login():loginRedirect triggered with ${JSON.stringify(request)}`);
                msal.loginRedirect(request);
            }
            logger.verbose(`useMsal.login():Returned`);
        }
        else {
            logger.verbose(`useMsal.login():Blocked due to other process is running (state=${inProgress.value})`);
        }
    };
    // Logout
    const logout = (logoutRequestOverrides) => {
        if (inProgress.value === msalBrowser.InteractionStatus.None) {
            logger.verbose(`useMsal.logout():Called`);
            const requestAccount = { account: msal.getActiveAccount() };
            if (interactionType === msalBrowser.InteractionType.Popup) {
                const request = logoutRequestOverrides != undefined
                    ? logoutRequestOverrides
                    : {
                        mainWindowRedirectUri: '/',
                        ...requestAccount,
                    };
                logger.verbose(`useMsal.logout():logoutPopup triggered with ${JSON.stringify(request)}`);
                msal.logoutPopup(request);
            }
            else if (interactionType == msalBrowser.InteractionType.Redirect) {
                const request = logoutRequestOverrides != undefined ? logoutRequestOverrides : requestAccount;
                logger.verbose(`useMsal.logout():logoutRedirect triggered with ${JSON.stringify(request)}`);
                msal.logoutRedirect(request);
            }
            logger.verbose(`useMsal.logout():Returned`);
        }
        else {
            logger.verbose(`useMsal.logout():Blocked due to other process is running (state=${inProgress.value})`);
        }
    };
    return {
        instance: msal,
        inProgress: inProgress,
        account: activeAccount,
        accounts: accounts,
        ops: {
            login: login,
            logout: logout,
        },
    };
}

// packages/vue-auth-msal/src/composables/useIsAuthenticated.ts
// Plugin Modules
/**
 * Function useIsAuthenticated
 * @returns
 * @public
 */
function useIsAuthenticated() {
    const { accounts } = useMsal();
    const isAuthenticated = vue.ref(accounts.value.length > 0);
    vue.watch(accounts, () => {
        isAuthenticated.value = accounts.value.length > 0;
    });
    return isAuthenticated;
}

// packages/vue-auth-msal/src/composables/useMsalAuthentication.ts
/* eslint-disable @typescript-eslint/no-explicit-any */
// Plugin Modules
/**
 * Function useMsalAuthentication
 * @returns
 * @public
 */
function useMsalAuthentication() {
    const plugin = useMsalPluginInstance();
    const interactionType = plugin.options.interactionType;
    const loginRequest = plugin.options.loginRequest;
    const logger = plugin.getLogger();
    const { instance, inProgress } = useMsal();
    const loginInteractionType = interactionType;
    const isInProgress = vue.ref(false);
    const result = vue.ref(null);
    const error = vue.ref(null);
    const acquireToken = async (requestOverride) => {
        logger.verbose(`useMsalAuthentication.acquireToken():Called`);
        if (!isInProgress.value) {
            // Lock
            isInProgress.value = true;
            // Process for handleRedirectPromise()
            if (inProgress.value === msalBrowser.InteractionStatus.HandleRedirect) {
                logger.verbose(`useMsalAuthentication.acquireToken():handleRedirectPromise triggered`);
                try {
                    const response = await instance.handleRedirectPromise();
                    if (response) {
                        logger.verbose(`useMsalAuthentication.acquireToken():handleRedirectPromise success response: ${JSON.stringify(response)}`);
                        result.value = response;
                        error.value = null;
                    }
                }
                catch (e) {
                    logger.verbose(`useMsalAuthentication.acquireToken():handleRedirectPromise error: ${JSON.stringify(e)}`);
                    result.value = null;
                    error.value = e;
                }
                isInProgress.value = false;
            }
            // Process for acquireToken()
            else if (inProgress.value === msalBrowser.InteractionStatus.None) {
                const tokenRequest = requestOverride || loginRequest;
                logger.verbose(`useMsalAuthentication.acquireToken():acquireTokenSilent triggered with ${JSON.stringify(tokenRequest)}`);
                try {
                    const response = await instance.acquireTokenSilent(tokenRequest);
                    logger.verbose(`useMsalAuthentication.acquireToken():acquireTokenSilent success response: ${JSON.stringify(response)}`);
                    result.value = response;
                    error.value = null;
                }
                catch (e) {
                    logger.verbose(`useMsalAuthentication.acquireToken():acquireTokenSilent error = ${JSON.stringify(e)}`);
                    // Try Login (Popup or Redirect) when no account error
                    if (e instanceof msalBrowser.InteractionRequiredAuthError ||
                        (e instanceof msalBrowser.BrowserAuthError &&
                            e.errorCode === msalBrowser.BrowserAuthErrorMessage.noAccountError.code &&
                            instance.getAllAccounts().length == 0)) {
                        logger.verbose(`useMsalAuthentication.acquireToken():interactive login triggered with ${JSON.stringify(tokenRequest)}`);
                        if (loginInteractionType === msalBrowser.InteractionType.Popup) {
                            await instance
                                .loginPopup(tokenRequest)
                                .then((response) => {
                                logger.verbose(`useMsalAuthentication.acquireToken():loginPopup success response: ${JSON.stringify(response)}`);
                                result.value = response;
                                error.value = null;
                            })
                                .catch((e) => {
                                result.value = null;
                                error.value = e;
                                if (e instanceof msalBrowser.BrowserAuthError &&
                                    e.errorCode === msalBrowser.BrowserAuthErrorMessage.userCancelledError.code) {
                                    logger.info(`useMsal.login():loginPopup user_cancelled`);
                                }
                                else {
                                    logger.error(`useMsal.login():loginPopup error: ${JSON.stringify(e)}`);
                                }
                            });
                        }
                        else {
                            await instance.loginRedirect(tokenRequest).catch((e) => {
                                logger.verbose(`useMsalAuthentication.acquireToken():loginRedirect error: ${JSON.stringify(e)}`);
                                result.value = null;
                                error.value = e;
                            });
                        }
                    }
                    // Other error cases
                    else {
                        result.value = null;
                        error.value = e;
                    }
                }
            }
            // Unlock
            isInProgress.value = false;
        }
        logger.verbose(`useMsalAuthentication.acquireToken():Returned`);
        return;
    };
    //await acquireToken()
    return {
        acquireToken: acquireToken,
        result: result,
        error: error,
    };
}

// packages/vue-auth-msal/src/composables/useAccount.ts
// Plugin Modules
/**
 * Function useAccount
 * @returns
 * @public
 */
function useAccount() {
    const plugin = useMsalPluginInstance();
    const interactionType = plugin.options.interactionType;
    const loginRequest = plugin.options.loginRequest;
    const logger = plugin.getLogger();
    const { account, instance } = useMsal();
    const username = vue.computed(() => {
        return account.value ? account.value.username : '(No username)';
    });
    const name = vue.computed(() => {
        return account.value != null && account.value.name != undefined ? account.value.name : '(No name)';
    });
    const switchAccount = async (newAccount) => {
        logger.verbose(`useAccount.switchAccount():Called`);
        const request = { ...loginRequest, account: newAccount, prompt: 'none' };
        try {
            logger.verbose(`useAccount.switchAccount():ssoClient triggered with: ${JSON.stringify(request)}`);
            await instance.ssoSilent(request).then((response) => {
                logger.verbose(`useAccount.switchAccount():ssoClient:success response: ${JSON.stringify(response)}`);
                if (response.account != null) {
                    instance.setActiveAccount(response.account);
                    account.value = instance.getActiveAccount();
                    logger.info(`useAccount.switchAccount():ssoClient set ActiveAccount: ${response.account.username}`);
                }
            });
        }
        catch (e) {
            logger.verbose(`useAccount.switchAccount():ssoClient error: ${JSON.stringify(e)}`);
            if (e instanceof msalBrowser.InteractionRequiredAuthError) {
                const interactiveRequest = { ...request, prompt: 'login' };
                if (interactionType === msalBrowser.InteractionType.Popup) {
                    instance
                        .loginPopup(interactiveRequest)
                        .then((response) => {
                        logger.verbose(`useAccount.switchAccount():loginPopup:success response: ${JSON.stringify(response)}`);
                        if (response.account != null) {
                            instance.setActiveAccount(response.account);
                            account.value = instance.getActiveAccount();
                            logger.info(`useAccount.switchAccount():loginPopup set ActiveAccount: ${response.account.username}`);
                        }
                    })
                        .catch((e) => {
                        logger.verbose(`useAccount.switchAccount():loginPopup error: ${JSON.stringify(e)}`);
                    });
                }
                else {
                    instance.loginRedirect(interactiveRequest).catch((e) => {
                        logger.verbose(`useAccount.switchAccount():loginRedirect error: ${JSON.stringify(e)}`);
                    });
                }
            }
        }
        logger.verbose(`useAccount.switchAccount():Returned`);
    };
    return {
        account: account,
        name: name,
        username: username,
        switchAccount: switchAccount,
    };
}

exports.MsalPlugin = MsalPlugin;
exports.createMsal = createMsal;
exports.pkgBuildDate = pkgBuildDate;
exports.pkgName = pkgName;
exports.pkgVersion = pkgVersion;
exports.useAccount = useAccount;
exports.useIsAuthenticated = useIsAuthenticated;
exports.useMsal = useMsal;
exports.useMsalAuthentication = useMsalAuthentication;
//# sourceMappingURL=vue-auth-msal.cjs.map
